@@ -167,6 +167,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_events
@@ -208,6 +210,9 @@ class EventBridgeDestination(
 
         :default: - use the default event bus
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EventBridgeDestination.__init__)
+            check_type(argname="argument event_bus", value=event_bus, expected_type=type_hints["event_bus"])
         jsii.create(self.__class__, self, [event_bus])
 
     @jsii.member(jsii_name="bind")
@@ -224,6 +229,10 @@ class EventBridgeDestination(
         :param fn: -
         :param type: The destination type.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(EventBridgeDestination.bind)
+            check_type(argname="argument _scope", value=_scope, expected_type=type_hints["_scope"])
+            check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
         _options = aws_cdk.aws_lambda.DestinationOptions(type=type)
 
         return typing.cast(aws_cdk.aws_lambda.DestinationConfig, jsii.invoke(self, "bind", [_scope, fn, _options]))
@@ -265,6 +274,9 @@ class LambdaDestination(
         :param fn: -
         :param response_only: Whether the destination function receives only the ``responsePayload`` of the source function. When set to ``true`` and used as ``onSuccess`` destination, the destination function will be invoked with the payload returned by the source function. When set to ``true`` and used as ``onFailure`` destination, the destination function will be invoked with the error object returned by source function. See the README of this module to see a full explanation of this option. Default: false The destination function receives the full invocation record.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaDestination.__init__)
+            check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
         options = LambdaDestinationOptions(response_only=response_only)
 
         jsii.create(self.__class__, self, [fn, options])
@@ -283,6 +295,10 @@ class LambdaDestination(
         :param fn: -
         :param type: The destination type.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaDestination.bind)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
         options = aws_cdk.aws_lambda.DestinationOptions(type=type)
 
         return typing.cast(aws_cdk.aws_lambda.DestinationConfig, jsii.invoke(self, "bind", [scope, fn, options]))
@@ -317,6 +333,9 @@ class LambdaDestinationOptions:
                 )
             )
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(LambdaDestinationOptions.__init__)
+            check_type(argname="argument response_only", value=response_only, expected_type=type_hints["response_only"])
         self._values: typing.Dict[str, typing.Any] = {}
         if response_only is not None:
             self._values["response_only"] = response_only
@@ -380,6 +399,9 @@ class SnsDestination(
         '''
         :param topic: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SnsDestination.__init__)
+            check_type(argname="argument topic", value=topic, expected_type=type_hints["topic"])
         jsii.create(self.__class__, self, [topic])
 
     @jsii.member(jsii_name="bind")
@@ -396,6 +418,10 @@ class SnsDestination(
         :param fn: -
         :param type: The destination type.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SnsDestination.bind)
+            check_type(argname="argument _scope", value=_scope, expected_type=type_hints["_scope"])
+            check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
         _options = aws_cdk.aws_lambda.DestinationOptions(type=type)
 
         return typing.cast(aws_cdk.aws_lambda.DestinationConfig, jsii.invoke(self, "bind", [_scope, fn, _options]))
@@ -431,6 +457,9 @@ class SqsDestination(
         '''
         :param queue: -
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SqsDestination.__init__)
+            check_type(argname="argument queue", value=queue, expected_type=type_hints["queue"])
         jsii.create(self.__class__, self, [queue])
 
     @jsii.member(jsii_name="bind")
@@ -447,6 +476,10 @@ class SqsDestination(
         :param fn: -
         :param type: The destination type.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(SqsDestination.bind)
+            check_type(argname="argument _scope", value=_scope, expected_type=type_hints["_scope"])
+            check_type(argname="argument fn", value=fn, expected_type=type_hints["fn"])
         _options = aws_cdk.aws_lambda.DestinationOptions(type=type)
 
         return typing.cast(aws_cdk.aws_lambda.DestinationConfig, jsii.invoke(self, "bind", [_scope, fn, _options]))
